
.. image:: https://img.shields.io/badge/OS-Climate-blue
  :alt: An OS-Climate Project
  :target: https://os-climate.org/

.. image:: https://img.shields.io/badge/slack-osclimate-brightgreen.svg?logo=slack
  :alt: Join OS-Climate on Slack
  :target: https://os-climate.slack.com

.. image:: https://img.shields.io/badge/GitHub-100000?logo=github&logoColor=white
  :alt: Source code on GitHub
  :target: https://github.com/ModeSevenIndustrialSolutions/osc-transformer-presteps

.. image:: https://img.shields.io/pypi/v/osc-transformer-presteps.svg
  :alt: PyPI package
  :target: https://pypi.org/project/osc-transformer-presteps/

.. image:: https://api.cirrus-ci.com/github/os-climate/osc-transformer-presteps.svg?branch=main
  :alt: Built Status
  :target: https://cirrus-ci.com/github/os-climate/osc-transformer-presteps

.. image:: https://img.shields.io/badge/PDM-Project-purple
  :alt: Built using PDM
  :target: https://pdm-project.org/latest/

.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
  :alt: Project generated with PyScaffold
  :target: https://pyscaffold.org/



========================
osc-transformer-presteps
========================

OS-Climate Data Extraction Tool

.. _notes:

Notes
=====

Placeholder notes content
